@@ -67,20 +67,6 @@ static void usage(void)
 	print_usage(stderr);
 }
 
-static int get_float(float *val, const char *arg)
-{
-	float res;
-	char *ptr;
-
-	if (!arg || !*arg)
-		return -1;
-	res = strtof(arg, &ptr);
-	if (!ptr || ptr == arg || *ptr)
-		return -1;
-	*val = res;
-	return 0;
-}
-
 static void set_ctrlmode(char *name, char *arg,
 			 struct can_ctrlmode *cm, __u32 flags)
 {
@@ -96,7 +82,7 @@ static void set_ctrlmode(char *name, char *arg,
 }
 
 static void print_flag(enum output_type t, __u32 *flags, __u32 flag,
-		       const char* name)
+		       const char *name)
 {
 	if (*flags & flag) {
 		*flags &= ~flag;
@@ -104,7 +90,7 @@ static void print_flag(enum output_type t, __u32 *flags, __u32 flag,
 	}
 }
 
-static void print_ctrlmode(enum output_type t, __u32 flags, const char* key)
+static void print_ctrlmode(enum output_type t, __u32 flags, const char *key)
 {
 	if (!flags)
 		return;
