@@ -79,7 +79,7 @@ static int gre_parse_opt(struct link_util *lu, int argc, char **argv,
 		.i.ifi_family = preferred_family,
 		.i.ifi_index = ifi->ifi_index,
 	};
-	struct nlmsghdr *answer;
+	struct nlmsghdr *answer = NULL;
 	struct rtattr *tb[IFLA_MAX + 1];
 	struct rtattr *linkinfo[IFLA_INFO_MAX+1];
 	struct rtattr *greinfo[IFLA_GRE_MAX + 1];
@@ -111,12 +111,8 @@ static int gre_parse_opt(struct link_util *lu, int argc, char **argv,
 	if (!(n->nlmsg_flags & NLM_F_CREATE)) {
 		const struct rtattr *rta;
 
-		if (rtnl_talk(&rth, &req.n, &answer) < 0) {
-get_failed:
-			fprintf(stderr,
-				"Failed to get existing tunnel info.\n");
-			return -1;
-		}
+		if (rtnl_talk(&rth, &req.n, &answer) < 0)
+			goto get_failed;
 
 		len = answer->nlmsg_len;
 		len -= NLMSG_LENGTH(sizeof(*ifi));
@@ -440,6 +436,11 @@ get_failed:
 	addattr16(n, 1024, IFLA_GRE_ENCAP_DPORT, htons(encapdport));
 
 	return 0;
+
+get_failed:
+	fprintf(stderr,	"Failed to get existing tunnel info.\n");
+	free(answer);
+	return -1;
 }
 
 static void gre_print_opt(struct link_util *lu, FILE *f, struct rtattr *tb[])
