@@ -620,7 +620,7 @@ static int pedit_keys_ex_addattr(struct m_pedit_sel *sel, struct nlmsghdr *n)
 	return 0;
 }
 
-static int parse_pedit(struct action_util *a, int *argc_p, char ***argv_p,
+static int parse_pedit(const struct action_util *a, int *argc_p, char ***argv_p,
 		       int tca_id, struct nlmsghdr *n)
 {
 	struct m_pedit_sel sel = {};
@@ -745,7 +745,7 @@ static int print_pedit_location(FILE *f,
 	return 0;
 }
 
-static int print_pedit(struct action_util *au, FILE *f, struct rtattr *arg)
+static int print_pedit(const struct action_util *au, FILE *f, struct rtattr *arg)
 {
 	struct tc_pedit_sel *sel;
 	struct rtattr *tb[TCA_PEDIT_MAX + 1];
@@ -771,27 +771,27 @@ static int print_pedit(struct action_util *au, FILE *f, struct rtattr *arg)
 		sel = RTA_DATA(tb[TCA_PEDIT_PARMS_EX]);
 
 		if (!tb[TCA_PEDIT_KEYS_EX]) {
-			fprintf(f, "Netlink error\n");
+			fprintf(stderr, "Netlink error\n");
 			return -1;
 		}
 
 		keys_ex = calloc(sel->nkeys, sizeof(*keys_ex));
 		if (!keys_ex) {
-			fprintf(f, "Out of memory\n");
+			fprintf(stderr, "Out of memory\n");
 			return -1;
 		}
 
 		err = pedit_keys_ex_getattr(tb[TCA_PEDIT_KEYS_EX], keys_ex,
 					    sel->nkeys);
 		if (err) {
-			fprintf(f, "Netlink error\n");
+			fprintf(stderr, "Netlink error\n");
 
 			free(keys_ex);
 			return -1;
 		}
 	}
 
-	print_action_control(f, "action ", sel->action, " ");
+	print_action_control("action ", sel->action, " ");
 	print_uint(PRINT_ANY, "nkeys", "keys %d\n", sel->nkeys);
 	print_uint(PRINT_ANY, "index", " \t index %u", sel->index);
 	print_int(PRINT_ANY, "ref", " ref %d", sel->refcnt);
@@ -801,7 +801,7 @@ static int print_pedit(struct action_util *au, FILE *f, struct rtattr *arg)
 		if (tb[TCA_PEDIT_TM]) {
 			struct tcf_t *tm = RTA_DATA(tb[TCA_PEDIT_TM]);
 
-			print_tm(f, tm);
+			print_tm(tm);
 		}
 	}
 	open_json_array(PRINT_JSON, "keys");
